@@ -111,8 +111,7 @@ class TransferJobPreprocessor:
 
     def process_body(self) -> dict:
         """
-        Injects AWS credentials into body if needed and
-        reformats schedule information.
+        Injects AWS credentials into body if needed and reformats schedule information.
 
         :return: Preprocessed body
         """
@@ -162,9 +161,10 @@ class TransferJobValidator:
 
     def validate_body(self) -> None:
         """
-        Validates the body. Checks if body specifies `transferSpec`
-        if yes, then check if AWS credentials are passed correctly and
-        no more than 1 data source was selected.
+        Validates the body.
+
+        Checks if body specifies `transferSpec` if yes, then check if AWS credentials
+        are passed correctly and no more than 1 data source was selected.
 
         :raises: AirflowException
         """
@@ -360,10 +360,11 @@ class CloudDataTransferServiceUpdateJobOperator(GoogleCloudBaseOperator):
 
 class CloudDataTransferServiceDeleteJobOperator(GoogleCloudBaseOperator):
     """
-    Delete a transfer job. This is a soft delete. After a transfer job is
-    deleted, the job and all the transfer executions are subject to garbage
-    collection. Transfer jobs become eligible for garbage collection
-    30 days after soft delete.
+    Delete a transfer job.
+
+    This is a soft delete. After a transfer job is deleted, the job and all the transfer
+    executions are subject to garbage collection. Transfer jobs become eligible for garbage
+    collection 30 days after soft delete.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -429,8 +430,7 @@ class CloudDataTransferServiceDeleteJobOperator(GoogleCloudBaseOperator):
 
 class CloudDataTransferServiceGetOperationOperator(GoogleCloudBaseOperator):
     """
-    Gets the latest state of a long-running operation in Google Storage Transfer
-    Service.
+    Gets the latest state of a long-running operation in Google Storage Transfer Service.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -503,8 +503,7 @@ class CloudDataTransferServiceGetOperationOperator(GoogleCloudBaseOperator):
 
 class CloudDataTransferServiceListOperationsOperator(GoogleCloudBaseOperator):
     """
-    Lists long-running operations in Google Storage Transfer
-    Service that match the specified filter.
+    Lists long-running operations in Google Storage Transfer Service that match the specified filter.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -766,8 +765,7 @@ class CloudDataTransferServiceCancelOperationOperator(GoogleCloudBaseOperator):
 
 class CloudDataTransferServiceS3ToGCSOperator(GoogleCloudBaseOperator):
     """
-    Synchronizes an S3 bucket with a Google Cloud Storage bucket using the
-    Google Cloud Storage Transfer Service.
+    Sync an S3 bucket with a Google Cloud Storage bucket using the Google Cloud Storage Transfer Service.
 
     .. warning::
 
