@@ -21,18 +21,17 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.spanner import SpannerHook
 from airflow.providers.google.cloud.links.spanner import SpannerDatabaseLink, SpannerInstanceLink
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class SpannerDeployInstanceOperator(BaseOperator):
+class SpannerDeployInstanceOperator(GoogleCloudBaseOperator):
     """
-    Creates a new Cloud Spanner instance, or if an instance with the same instance_id
-    exists in the specified project, updates the Cloud Spanner instance.
+    Create or update a Cloud Spanner instance.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -62,12 +61,12 @@ class SpannerDeployInstanceOperator(BaseOperator):
 
     # [START gcp_spanner_deploy_template_fields]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'configuration_name',
-        'display_name',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "configuration_name",
+        "display_name",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END gcp_spanner_deploy_template_fields]
     operator_extra_links = (SpannerInstanceLink(),)
@@ -80,7 +79,7 @@ class SpannerDeployInstanceOperator(BaseOperator):
         node_count: int,
         display_name: str,
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -95,7 +94,7 @@ class SpannerDeployInstanceOperator(BaseOperator):
         super().__init__(**kwargs)
 
     def _validate_inputs(self) -> None:
-        if self.project_id == '':
+        if self.project_id == "":
             raise AirflowException("The required parameter 'project_id' is empty")
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
@@ -126,10 +125,9 @@ class SpannerDeployInstanceOperator(BaseOperator):
         )
 
 
-class SpannerDeleteInstanceOperator(BaseOperator):
+class SpannerDeleteInstanceOperator(GoogleCloudBaseOperator):
     """
-    Deletes a Cloud Spanner instance. If an instance does not exist,
-    no action is taken and the operator succeeds.
+    Delete a Cloud Spanner instance; if an instance does not exist, no action is taken and the task succeeds.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -151,10 +149,10 @@ class SpannerDeleteInstanceOperator(BaseOperator):
 
     # [START gcp_spanner_delete_template_fields]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END gcp_spanner_delete_template_fields]
 
@@ -163,7 +161,7 @@ class SpannerDeleteInstanceOperator(BaseOperator):
         *,
         instance_id: str,
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -175,7 +173,7 @@ class SpannerDeleteInstanceOperator(BaseOperator):
         super().__init__(**kwargs)
 
     def _validate_inputs(self) -> None:
-        if self.project_id == '':
+        if self.project_id == "":
             raise AirflowException("The required parameter 'project_id' is empty")
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
@@ -196,7 +194,7 @@ class SpannerDeleteInstanceOperator(BaseOperator):
             return True
 
 
-class SpannerQueryDatabaseInstanceOperator(BaseOperator):
+class SpannerQueryDatabaseInstanceOperator(GoogleCloudBaseOperator):
     """
     Executes an arbitrary DML query (INSERT, UPDATE, DELETE).
 
@@ -223,15 +221,15 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
 
     # [START gcp_spanner_query_template_fields]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'database_id',
-        'query',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "database_id",
+        "query",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
-    template_ext: Sequence[str] = ('.sql',)
-    template_fields_renderers = {'query': 'sql'}
+    template_ext: Sequence[str] = (".sql",)
+    template_fields_renderers = {"query": "sql"}
     # [END gcp_spanner_query_template_fields]
     operator_extra_links = (SpannerDatabaseLink(),)
 
@@ -242,7 +240,7 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
         database_id: str,
         query: str | list[str],
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -256,7 +254,7 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
         super().__init__(**kwargs)
 
     def _validate_inputs(self) -> None:
-        if self.project_id == '':
+        if self.project_id == "":
             raise AirflowException("The required parameter 'project_id' is empty")
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
@@ -271,7 +269,7 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
             impersonation_chain=self.impersonation_chain,
         )
         if isinstance(self.query, str):
-            queries = [x.strip() for x in self.query.split(';')]
+            queries = [x.strip() for x in self.query.split(";")]
             self.sanitize_queries(queries)
         else:
             queries = self.query
@@ -302,16 +300,14 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
         Drops empty query in queries.
 
         :param queries: queries
-        :rtype: None
         """
-        if queries and queries[-1] == '':
+        if queries and queries[-1] == "":
             del queries[-1]
 
 
-class SpannerDeployDatabaseInstanceOperator(BaseOperator):
+class SpannerDeployDatabaseInstanceOperator(GoogleCloudBaseOperator):
     """
-    Creates a new Cloud Spanner database, or if database exists,
-    the operator does nothing.
+    Creates a new Cloud Spanner database; if database exists, the operator does nothing.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -335,15 +331,15 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
 
     # [START gcp_spanner_database_deploy_template_fields]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'database_id',
-        'ddl_statements',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "database_id",
+        "ddl_statements",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
-    template_ext: Sequence[str] = ('.sql',)
-    template_fields_renderers = {'ddl_statements': 'sql'}
+    template_ext: Sequence[str] = (".sql",)
+    template_fields_renderers = {"ddl_statements": "sql"}
     # [END gcp_spanner_database_deploy_template_fields]
     operator_extra_links = (SpannerDatabaseLink(),)
 
@@ -354,7 +350,7 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
         database_id: str,
         ddl_statements: list[str],
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -368,7 +364,7 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
         super().__init__(**kwargs)
 
     def _validate_inputs(self) -> None:
-        if self.project_id == '':
+        if self.project_id == "":
             raise AirflowException("The required parameter 'project_id' is empty")
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
@@ -413,7 +409,7 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
         return True
 
 
-class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
+class SpannerUpdateDatabaseInstanceOperator(GoogleCloudBaseOperator):
     """
     Updates a Cloud Spanner database with the specified DDL statement.
 
@@ -441,15 +437,15 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
 
     # [START gcp_spanner_database_update_template_fields]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'database_id',
-        'ddl_statements',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "database_id",
+        "ddl_statements",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
-    template_ext: Sequence[str] = ('.sql',)
-    template_fields_renderers = {'ddl_statements': 'sql'}
+    template_ext: Sequence[str] = (".sql",)
+    template_fields_renderers = {"ddl_statements": "sql"}
     # [END gcp_spanner_database_update_template_fields]
     operator_extra_links = (SpannerDatabaseLink(),)
 
@@ -461,7 +457,7 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
         ddl_statements: list[str],
         project_id: str | None = None,
         operation_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -476,7 +472,7 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
         super().__init__(**kwargs)
 
     def _validate_inputs(self) -> None:
-        if self.project_id == '':
+        if self.project_id == "":
             raise AirflowException("The required parameter 'project_id' is empty")
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
@@ -515,7 +511,7 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
             )
 
 
-class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
+class SpannerDeleteDatabaseInstanceOperator(GoogleCloudBaseOperator):
     """
     Deletes a Cloud Spanner database.
 
@@ -540,11 +536,11 @@ class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
 
     # [START gcp_spanner_database_delete_template_fields]
     template_fields: Sequence[str] = (
-        'project_id',
-        'instance_id',
-        'database_id',
-        'gcp_conn_id',
-        'impersonation_chain',
+        "project_id",
+        "instance_id",
+        "database_id",
+        "gcp_conn_id",
+        "impersonation_chain",
     )
     # [END gcp_spanner_database_delete_template_fields]
 
@@ -554,7 +550,7 @@ class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
         instance_id: str,
         database_id: str,
         project_id: str | None = None,
-        gcp_conn_id: str = 'google_cloud_default',
+        gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -567,7 +563,7 @@ class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
         super().__init__(**kwargs)
 
     def _validate_inputs(self) -> None:
-        if self.project_id == '':
+        if self.project_id == "":
             raise AirflowException("The required parameter 'project_id' is empty")
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
