@@ -133,8 +133,8 @@ class BigQueryTableExistenceSensor(BaseSensorOperator):
     def execute_complete(self, context: dict[str, Any], event: dict[str, str] | None = None) -> str:
         """
         Callback for when the trigger fires - returns immediately.
-        Relies on trigger to throw an exception, otherwise it assumes execution was
-        successful.
+
+        Relies on trigger to throw an exception, otherwise it assumes execution was successful.
         """
         table_uri = f"{self.project_id}:{self.dataset_id}.{self.table_id}"
         self.log.info("Sensor checks existence of table: %s", table_uri)
@@ -216,10 +216,7 @@ class BigQueryTablePartitionExistenceSensor(BaseSensorOperator):
         )
 
     def execute(self, context: Context) -> None:
-        """
-        Airflow runs this method on the worker and defers using the triggers
-        if deferrable is set to True.
-        """
+        """Airflow runs this method on the worker and defers using the triggers if deferrable is True."""
         if not self.deferrable:
             super().execute(context)
         else:
@@ -243,8 +240,8 @@ class BigQueryTablePartitionExistenceSensor(BaseSensorOperator):
     def execute_complete(self, context: dict[str, Any], event: dict[str, str] | None = None) -> str:
         """
         Callback for when the trigger fires - returns immediately.
-        Relies on trigger to throw an exception, otherwise it assumes execution was
-        successful.
+
+        Relies on trigger to throw an exception, otherwise it assumes execution was successful.
         """
         table_uri = f"{self.project_id}:{self.dataset_id}.{self.table_id}"
         self.log.info('Sensor checks existence of partition: "%s" in table: %s', self.partition_id, table_uri)
