@@ -15,10 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-This module contains operator for copying
-data from Cassandra to Google Cloud Storage in JSON format.
-"""
+"""This module contains operator for copying data from Cassandra to Google Cloud Storage in JSON format."""
+
 from __future__ import annotations
 
 import json
@@ -220,8 +218,7 @@ class CassandraToGCSOperator(BaseOperator):
 
     def _write_local_schema_file(self, cursor):
         """
-        Takes a cursor, and writes the BigQuery schema for the results to a
-        local file system.
+        Takes a cursor, and writes the BigQuery schema for the results to a local file system.
 
         :return: A dictionary where key is a filename to be used as an object
             name in GCS, and values are file handles to local files that
@@ -295,9 +292,9 @@ class CassandraToGCSOperator(BaseOperator):
 
     def convert_user_type(self, value: Any) -> dict[str, Any]:
         """
-        Converts a user type to RECORD that contains n fields, where n is the
-        number of attributes. Each element in the user type class will be converted to its
-        corresponding data type in BQ.
+        Converts a user type to RECORD that contains n fields, where n is the number of attributes.
+
+        Each element in the user type class will be converted to its corresponding data type in BQ.
         """
         names = value._fields
         values = [self.convert_value(getattr(value, name)) for name in names]
@@ -305,17 +302,20 @@ class CassandraToGCSOperator(BaseOperator):
 
     def convert_tuple_type(self, values: tuple[Any]) -> dict[str, Any]:
         """
-        Converts a tuple to RECORD that contains n fields, each will be converted
-        to its corresponding data type in bq and will be named 'field_<index>', where
-        index is determined by the order of the tuple elements defined in cassandra.
+        Converts a tuple to RECORD that contains n fields.
+
+        Each field will be converted to its corresponding data type in bq and
+        will be named 'field_<index>', where index is determined by the order
+        of the tuple elements defined in cassandra.
         """
         names = ["field_" + str(i) for i in range(len(values))]
         return self.generate_data_dict(names, values)
 
     def convert_map_type(self, value: OrderedMapSerializedKey) -> list[dict[str, Any]]:
         """
-        Converts a map to a repeated RECORD that contains two fields: 'key' and 'value',
-        each will be converted to its corresponding data type in BQ.
+        Converts a map to a repeated RECORD that contains two fields: 'key' and 'value'.
+
+        Each will be converted to its corresponding data type in BQ.
         """
         converted_map = []
         for k, v in zip(value.keys(), value.values()):
