@@ -75,29 +75,29 @@ class PostgresToGCSOperator(BaseSQLToGCSOperator):
     :param cursor_itersize: How many records are fetched at a time in case of server-side cursor.
     """
 
-    ui_color = '#a0e08c'
+    ui_color = "#a0e08c"
 
     type_map = {
-        1114: 'DATETIME',
-        1184: 'TIMESTAMP',
-        1082: 'DATE',
-        1083: 'TIME',
-        1005: 'INTEGER',
-        1007: 'INTEGER',
-        1016: 'INTEGER',
-        20: 'INTEGER',
-        21: 'INTEGER',
-        23: 'INTEGER',
-        16: 'BOOL',
-        700: 'FLOAT',
-        701: 'FLOAT',
-        1700: 'FLOAT',
+        1114: "DATETIME",
+        1184: "TIMESTAMP",
+        1082: "DATE",
+        1083: "TIME",
+        1005: "INTEGER",
+        1007: "INTEGER",
+        1016: "INTEGER",
+        20: "INTEGER",
+        21: "INTEGER",
+        23: "INTEGER",
+        16: "BOOL",
+        700: "FLOAT",
+        701: "FLOAT",
+        1700: "FLOAT",
     }
 
     def __init__(
         self,
         *,
-        postgres_conn_id='postgres_default',
+        postgres_conn_id="postgres_default",
         use_server_side_cursor=False,
         cursor_itersize=2000,
         **kwargs,
@@ -123,15 +123,15 @@ class PostgresToGCSOperator(BaseSQLToGCSOperator):
 
     def field_to_bigquery(self, field) -> dict[str, str]:
         return {
-            'name': field[0],
-            'type': self.type_map.get(field[1], "STRING"),
-            'mode': 'REPEATED' if field[1] in (1009, 1005, 1007, 1016) else 'NULLABLE',
+            "name": field[0],
+            "type": self.type_map.get(field[1], "STRING"),
+            "mode": "REPEATED" if field[1] in (1009, 1005, 1007, 1016) else "NULLABLE",
         }
 
     def convert_type(self, value, schema_type, stringify_dict=True):
         """
-        Takes a value from Postgres, and converts it to a value that's safe for
-        JSON/Google Cloud Storage/BigQuery.
+        Take a value from Postgres and convert it to a value safe for JSON/Google Cloud Storage/BigQuery.
+
         Timezone aware Datetime are converted to UTC seconds.
         Unaware Datetime, Date and Time are converted to ISO formatted strings.
         Decimals are converted to floats.
