@@ -18,11 +18,15 @@
 from __future__ import annotations
 
 import asyncio
+import warnings
 from datetime import datetime
 from typing import Any, AsyncIterator, Sequence
 
 from google.cloud.container_v1.types import Operation
 
+from airflow.exceptions import AirflowProviderDeprecationWarning
+from airflow.providers.cncf.kubernetes.utils.pod_manager import OnFinishAction
+
 try:
     from airflow.providers.cncf.kubernetes.triggers.pod import KubernetesPodTrigger
 except ImportError:
@@ -44,15 +48,19 @@ class GKEStartPodTrigger(KubernetesPodTrigger):
     :param poll_interval: Polling period in seconds to check for the status.
     :param trigger_start_time: time in Datetime format when the trigger was started
     :param in_cluster: run kubernetes client with in_cluster configuration.
-    :param should_delete_pod: What to do when the pod reaches its final
-        state, or the execution is interrupted. If True (default), delete the
-        pod; if False, leave the pod.
     :param get_logs: get the stdout of the container as logs of the tasks.
     :param startup_timeout: timeout in seconds to start up the pod.
     :param base_container_name: The name of the base container in the pod. This container's logs
         will appear as part of this task's logs if get_logs is True. Defaults to None. If None,
         will consult the class variable BASE_CONTAINER_NAME (which defaults to "base") for the base
         container name to use.
+    :param on_finish_action: What to do when the pod reaches its final state, or the execution is interrupted.
+        If "delete_pod", the pod will be deleted regardless it's state; if "delete_succeeded_pod",
+        only succeeded pod will be deleted. You can set to "keep_pod" to keep the pod.
+    :param should_delete_pod: What to do when the pod reaches its final
+        state, or the execution is interrupted. If True (default), delete the
+        pod; if False, leave the pod.
+        Deprecated - use `on_finish_action` instead.
     """
 
     def __init__(
@@ -66,9 +74,10 @@ class GKEStartPodTrigger(KubernetesPodTrigger):
         cluster_context: str | None = None,
         poll_interval: float = 2,
         in_cluster: bool | None = None,
-        should_delete_pod: bool = True,
         get_logs: bool = True,
         startup_timeout: int = 120,
+        on_finish_action: str = "delete_pod",
+        should_delete_pod: bool | None = None,
         *args,
         **kwargs,
     ):
@@ -87,10 +96,22 @@ class GKEStartPodTrigger(KubernetesPodTrigger):
         self.poll_interval = poll_interval
         self.cluster_context = cluster_context
         self.in_cluster = in_cluster
-        self.should_delete_pod = should_delete_pod
         self.get_logs = get_logs
         self.startup_timeout = startup_timeout
 
+        if should_delete_pod is not None:
+            warnings.warn(
+                "`should_delete_pod` parameter is deprecated, please use `on_finish_action`",
+                AirflowProviderDeprecationWarning,
+            )
+            self.on_finish_action = (
+                OnFinishAction.DELETE_POD if should_delete_pod else OnFinishAction.KEEP_POD
+            )
+            self.should_delete_pod = should_delete_pod
+        else:
+            self.on_finish_action = OnFinishAction(on_finish_action)
+            self.should_delete_pod = self.on_finish_action == OnFinishAction.DELETE_POD
+
         self._cluster_url = cluster_url
         self._ssl_ca_cert = ssl_ca_cert
 
@@ -105,11 +126,12 @@ class GKEStartPodTrigger(KubernetesPodTrigger):
                 "poll_interval": self.poll_interval,
                 "cluster_context": self.cluster_context,
                 "in_cluster": self.in_cluster,
-                "should_delete_pod": self.should_delete_pod,
                 "get_logs": self.get_logs,
                 "startup_timeout": self.startup_timeout,
                 "trigger_start_time": self.trigger_start_time,
                 "base_container_name": self.base_container_name,
+                "should_delete_pod": self.should_delete_pod,
+                "on_finish_action": self.on_finish_action.value,
             },
         )
 
